@@ -153,7 +153,7 @@ class Monitor(threading.Thread):
             packet = pkt[14:-1]
             packet = hexlify(packet).decode().upper()
             dec = decode(packet, self.ruuviPlus)
-            if(dec['dataFormat' != 0]): #Beacon most likely ibeacon or eddstone URL/UID. FIX needed
+            if(dec['dataFormat'] != 0): #Beacon most likely ibeacon or eddstone URL/UID. FIX needed
                 smoothRSSI = self.rHistory(bt_addr, rssi)
                 if smoothRSSI >= self.rssiThreshold:
                     self.callback(bt_addr, rssi, packet, dec, smoothRSSI)
